#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 cheapskate
version:              0.1.1.2
visibility:           public
id:                   cheapskate-0.1.1.2-5KvKHIipSadJaIDP1BewJq
key:                  cheapskate-0.1.1.2-5KvKHIipSadJaIDP1BewJq
license:              BSD-3-Clause
copyright:            (C) 2012-2013 John MacFarlane
maintainer:           jgm@berkeley.edu
author:               John MacFarlane
homepage:             http://github.com/jgm/cheapskate
synopsis:             Experimental markdown processor.
description:
    This is an experimental Markdown processor in pure
    Haskell.  It aims to process Markdown efficiently and in
    the most forgiving possible way.  It is designed to deal
    with any input, including garbage, with linear
    performance.  Output is sanitized by default for
    protection against XSS attacks.

    Several markdown extensions are implemented, including
    fenced code blocks, significant list start numbers, and
    autolinked URLs.  See README.markdown for details.

category:             Text
abi:                  e4618d88cc68b98509a9fe593ef65a96
exposed:              True
exposed-modules:
    Cheapskate Cheapskate.Html Cheapskate.Parse Cheapskate.Types

hidden-modules:
    Cheapskate.Util Cheapskate.Inlines Cheapskate.ParserCombinators
    Paths_cheapskate

import-dirs:          /usr/lib/ghc-9.6.6/site-local/cheapskate-0.1.1.2
library-dirs:         /usr/lib/ghc-9.6.6/site-local/cheapskate-0.1.1.2
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/cheapskate-0.1.1.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-cheapskate
hs-libraries:         HScheapskate-0.1.1.2-5KvKHIipSadJaIDP1BewJq
depends:
    base-4.18.2.1 blaze-html-0.9.2.0-3zJbEruN1MK4AfSPvaGc85
    containers-0.6.7 data-default-0.7.1.3-EtVHsfbH5oIpJ9umzYHUz
    deepseq-1.4.8.1 mtl-2.3.1 syb-0.7.3-IWvKvWWONKwAx7053zcTAl
    text-2.0.2 uniplate-1.6.13-7y3rluGnYuPKDSppbqd6yK
    xss-sanitize-0.3.7.2-94kOfjVrJYN1ppoOSC7EiN

haddock-interfaces:   /usr/share/doc/haskell-cheapskate/html/cheapskate.haddock
haddock-html:         /usr/share/doc/haskell-cheapskate/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

